var namespace;

namespace = function(path, obj) {
  var i, len, part, ref, root;
  root = obj || this;
  ref = path.split('.');
  for (i = 0, len = ref.length; i < len; i++) {
    part = ref[i];
    root[part] || (root[part] = {});
    root = root[part];
  }
  return root;
};

ruGeoLocalizationSupportedLocales = function() {
  return ["ru","en"];
};

ruGeoLocalizationLocaleTranslations = function() {
  return {"ru":"ru/mustache.json","en":"en/mustache.json"};
}

namespace('ru.geo.cookie');

ru.geo.cookie.get = function(name) {
  var matches;
  matches = document.cookie.match(new RegExp('(?:^|; )' + name.replace(/([\.$?*|{}\(\)\[\]\\\/\+^])/g, '\\$1') + '=([^;]*)'));
  if (matches) {
    return decodeURIComponent(matches[1]);
  } else {
    return void 0;
  }
};

ru.geo.cookie.set = function(name, value, options) {
  var d, expires, propName, propValue, updatedCookie;
  options = options || {};
  expires = options.expires;
  if (typeof expires === 'number' && expires) {
    d = new Date;
    d.setTime(d.getTime() + expires * 1000);
    expires = options.expires = d;
  }
  if (expires && expires.toUTCString) {
    options.expires = expires.toUTCString();
  }
  value = encodeURIComponent(value);
  updatedCookie = name + '=' + value;
  for (propName in options) {
    updatedCookie += '; ' + propName;
    propValue = options[propName];
    if (propValue !== true) {
      updatedCookie += '=' + propValue;
    }
  }
  document.cookie = updatedCookie;
};

/* MultiFile - A JavaScript library to load multiple files from
   tar archives and json_packed files (see http://gist.github.com/407595)

  Example: Loading multiple images from a tarball.

  MultiFile.load('images.tar', function(xhr) {
    this.files.forEach(function(f) {
      var e = document.createElement('div');
      document.body.appendChild(e);
      var p = document.createElement('p');
      p.appendChild(document.createTextNode(f.filename + " (" + f.length + " bytes)"));
      e.appendChild(p);
      var img = new Image();
      img.src = f.toDataURL();
      e.appendChild(img);
    });
  });

  Example 2: Streaming images from a tarball.

  MultiFile.stream('images.tar', function(f) {
      var e = document.createElement('div');
      document.body.appendChild(e);
      var p = document.createElement('p');
      p.appendChild(document.createTextNode(f.filename + " (" + f.length + " bytes)"));
      e.appendChild(p);
      var img = new Image();
      img.src = f.toDataURL();
      e.appendChild(img);
  });


Copyright (c) 2010 Ilmari Heikkinen

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/

MultiFile = function(){};

// Load and parse archive, calls onload after loading all files.
MultiFile.load = function(url, onload) {
  var o = new MultiFile();
  o.onload = onload;
  o.load(url);
  return o;
}

// Streams an archive from the given url, calling onstream after loading each file in archive.
// Calls onload after loading all files.
MultiFile.stream = function(url, onstream, onload) {
  var o = new MultiFile();
  o.onload = onload;
  o.onstream = onstream;
  o.load(url);
  return o;
}
MultiFile.prototype = {
  onerror : null,
  onload : null,
  onstream : null,

  base64Encode : function(str) {
    var CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
    var out = "", i = 0, len = str.length, c1, c2, c3;
    while (i < len) {
        c1 = str.charCodeAt(i++) & 0xff;
        if (i == len) {
            out += CHARS.charAt(c1 >> 2);
            out += CHARS.charAt((c1 & 0x3) << 4);
            out += "==";
            break;
        }
        c2 = str.charCodeAt(i++);
        if (i == len) {
            out += CHARS.charAt(c1 >> 2);
            out += CHARS.charAt(((c1 & 0x3)<< 4) | ((c2 & 0xF0) >> 4));
            out += CHARS.charAt((c2 & 0xF) << 2);
            out += "=";
            break;
        }
        c3 = str.charCodeAt(i++);
        out += CHARS.charAt(c1 >> 2);
        out += CHARS.charAt(((c1 & 0x3) << 4) | ((c2 & 0xF0) >> 4));
        out += CHARS.charAt(((c2 & 0xF) << 2) | ((c3 & 0xC0) >> 6));
        out += CHARS.charAt(c3 & 0x3F);
    }
    return out;
  },

  load : function(url) {
    var xhr = new XMLHttpRequest();
    var self = this;
    var offset = 0;
    this.files = [];
    var isTar = (/\.tar(\?.*)?$/i).test(url);
    xhr.onreadystatechange = function() {
      if (xhr.readyState == 4) {
        if (xhr.status == 200 || xhr.status == 0) {
          if (isTar)
            offset = self.processTarChunks(xhr.responseText, offset);
          else
            self.processJSONChunks(xhr.responseText);
          if (self.onload)
            self.onload(xhr);
        } else {
          if (self.onerror)
            self.onerror(xhr);
        }
      } else if (xhr.readyState == 3) {
        if (xhr.status == 200 || xhr.status == 0) {
          if (isTar)
            offset = self.processTarChunks(xhr.responseText, offset);
          else
            self.processJSONChunks(xhr.responseText);
        }
      }
    };
    xhr.open("GET", url, true);
    xhr.overrideMimeType("text/plain; charset=x-user-defined");
    xhr.setRequestHeader("Content-Type", "application/octet-stream");
    xhr.send(null);
  },

  onerror : function(xhr) {
    alert("Error: "+xhr.status);
  },

  parseJSON : function(text) {
    this.processJSONChunks(text);
  },
  processJSONChunks : function(text) {
    if (this.files.length == 0) { // processing headers
      var idx = text.indexOf('\n');
      if (idx >= 0) { // got header
        this.files = JSON.parse(text.substring(0,idx));
        this.files.forEach(function(f) { f.offset += idx + 1; })
      }
    }
    if (this.files.length > 0) { // processing data
      var f = null;
      var idx=0;
      for (idx=0; idx<this.files.length; idx++) {
        if (this.files[idx].data == null) {
          f = this.files[idx];
          break;
        }
      }
      while (f && f.data == null && f.offset + f.length <= text.length) {
        f.data = text.substring(f.offset, f.offset + f.length);
        f.toDataURL = this.__toDataURL;
        if (this.onstream) this.onstream(f);
        f = this.files[idx++];
      }
    }
  },

  cleanHighByte : function(s) {
    return s.replace(/./g, function(m) {
      return String.fromCharCode(m.charCodeAt(0) & 0xff);
    });
  },

  parseTar : function(text) {
    this.files = [];
    this.processTarChunks(text, 0);
  },
  processTarChunks : function (responseText, offset) {
    var self = this;
    makeUint8Array = function(str) {
      try {
        var arr = new Uint8Array(str.length);
        for (var i = 0, len = str.length; i < len; ++i) arr[i] = str.charCodeAt(i);
        return arr;
      } catch(e) {
        return { base64Encoded: self.base64Encode(str) };
      }
    }


    while (responseText.length >= offset + 512) {
      var header = this.files.length == 0 ? null : this.files[this.files.length-1];
      if (header && header.data == null) {
        if (offset + header.length <= responseText.length) {
          header.data = makeUint8Array(responseText.substring(offset, offset+header.length));

          header.toDataURL = this.__toDataURL;
          offset += 512 * Math.ceil(header.length / 512);
          if (this.onstream)
            this.onstream(header);
        } else { // not loaded yet
          break;
        }
      } else {
        var header = this.parseTarHeader(responseText, offset);
        if (header.length > 0 || header.filename != '') {
          this.files.push(header);
          offset += 512;
          header.offset = offset;
        } else { // empty header, stop processing
          offset = responseText.length;
        }
      }
    }
    return offset;
  },
  parseTarHeader : function(text, offset) {
    var i = offset || 0;
    var h = {};
    h.filename = text.substring(i, i+=100).split("\0", 1)[0];
    h.mode = text.substring(i, i+=8).split("\0", 1)[0];
    h.uid = text.substring(i, i+=8).split("\0", 1)[0];
    h.gid = text.substring(i, i+=8).split("\0", 1)[0];
    h.length = this.parseTarNumber(text.substring(i, i+=12));
    h.lastModified = text.substring(i, i+=12).split("\0", 1)[0];
    h.checkSum = text.substring(i, i+=8).split("\0", 1)[0];
    h.fileType = text.substring(i, i+=1).split("\0", 1)[0];
    h.linkName = text.substring(i, i+=100).split("\0", 1)[0];
    return h;
  },
  parseTarNumber : function(text) {
    // if (text.charCodeAt(0) & 0x80 == 1) {
    // GNU tar 8-byte binary big-endian number
    // } else {
      // return parseInt('0'+text.replace(/[^\d]/g, ''));
      return parseInt(text.replace(/^0*/, ''), 8) || 0;
    // }
  },

  __toDataURL : function() {
    if (this.data.substring(0,40).match(/^data:[^\/]+\/[^,]+,/)) {
      return this.data;
    } else if (MultiFile.prototype.cleanHighByte(this.data.substring(0,10)).match(/\377\330\377\340..JFIF/)) {
      return 'data:image/jpeg;base64,'+btoa(MultiFile.prototype.cleanHighByte(this.data));
    } else if (MultiFile.prototype.cleanHighByte(this.data.substring(0,6)) == "\211PNG\r\n") {
      return 'data:image/png;base64,'+btoa(MultiFile.prototype.cleanHighByte(this.data));
    } else if (MultiFile.prototype.cleanHighByte(this.data.substring(0,6)).match(/GIF8[79]a/)) {
      return 'data:image/gif;base64,'+btoa(MultiFile.prototype.cleanHighByte(this.data));
    } else {
      throw("toDataURL: I don't know how to handle " + this.filename);
    }
  }
}


namespace('ru.geo.Provider');

ru.geo.Provider.fourGeo = '4geo';

ru.geo.Provider.osm = 'osm';

ru.geo.Provider.ids = {
  fourGeo: 0,
  osm: {
    node: 1,
    way: 2,
    relation: 3,
    shape: 4
  }
};

ru.geo.Provider.toString = function(id) {
  if (id === ru.geo.Provider.ids.fourGeo) {
    return ru.geo.Provider.fourGeo;
  }
  return ru.geo.Provider.osm;
};

ru.geo.Provider.is4geoProvider = function(provider) {
  return provider === ru.geo.Provider.ids.fourGeo;
};

namespace('sys.xhr');

sys.xhr.makeXhr = function() {
  var xhr;
  try {
    if (window.ActiveXObject) {
      xhr = new ActiveXObject('Microsoft.XMLHTTP');
    }
  } catch (error1) {

  }
  if (!xhr) {
    return xhr = new XMLHttpRequest();
  }
};

sys.xhr.getJson = function(url, success) {
  var xhr;
  xhr = sys.xhr.makeXhr();
  xhr.onreadystatechange = function() {
    var e;
    if (xhr.readyState === 4) {
      if (xhr.status === 200 || xhr.status === 0) {
        try {
          success(xhr.responseText);
        } catch (error1) {
          e = error1;
          if (typeof console !== "undefined" && console !== null) {
            console.error(JSON.stringify(e != null ? e.message : void 0));
          }
          success('{}');
        }
        return;
      }
      return success('{}');
    }
  };
  xhr.open('GET', url, true);
  xhr.setRequestHeader('Content-Type', 'application/json');
  return xhr.send();
};

sys.xhr.getWithTimeout = function(url, success, error, timeout) {
  var abortTimeout, onTimeout, xhr;
  xhr = sys.xhr.makeXhr();
  xhr.onreadystatechange = function() {
    var e, ref, ref1;
    if (xhr.readyState === 4) {
      clearTimeout(abortTimeout);
      if (((ref = xhr.status) === 0 || ref === 200) && ((ref1 = xhr.responseText) != null ? ref1.trim() : void 0)) {
        try {
          success(xhr.responseText);
        } catch (error1) {
          e = error1;
          if (typeof error === "function") {
            error();
          }
        }
        return;
      }
      return typeof error === "function" ? error() : void 0;
    }
  };
  if (timeout) {
    onTimeout = function() {
      return xhr.abort();
    };
    abortTimeout = setTimeout(onTimeout, timeout);
  }
  xhr.open('GET', url, true);
  return xhr.send();
};

sys.xhr.get = function(url, success, error) {
  return sys.xhr.getWithTimeout(url, success, error, null);
};

sys.xhr.getArrayBuffer = function(url, success, error) {
  var xhr;
  xhr = sys.xhr.makeXhr();
  xhr.onreadystatechange = function() {
    var e;
    if (xhr.readyState === 4) {
      if (xhr.status === 200 || xhr.status === 0) {
        try {
          success(xhr.response);
        } catch (error1) {
          e = error1;
          if (typeof console !== "undefined" && console !== null) {
            console.error(JSON.stringify(e != null ? e.message : void 0));
          }
          if (typeof error === "function") {
            error();
          }
        }
        return;
      }
      return typeof error === "function" ? error() : void 0;
    }
  };
  xhr.open('GET', url, true);
  xhr.setRequestHeader('Content-Type', 'application/octet-stream');
  xhr.responseType = 'arraybuffer';
  return xhr.send();
};

namespace('sys.bundle');

sys.bundle.canUpdateWithVersion = function(currentVersionInfo, newVersionInfo) {
  var currentVersion, e, newVersion, ref;
  if (!(((currentVersionInfo != null ? currentVersionInfo.bundle : void 0) != null) && ((newVersionInfo != null ? newVersionInfo.bundle : void 0) != null) && ((currentVersionInfo != null ? currentVersionInfo.core : void 0) != null) && (currentVersionInfo.core.toString() === (newVersionInfo != null ? (ref = newVersionInfo.core) != null ? ref.toString() : void 0 : void 0)))) {
    return false;
  }
  currentVersion = currentVersionInfo.bundle;
  newVersion = newVersionInfo.bundle;
  try {
    newVersion = parseInt(newVersion);
    if (currentVersionInfo.bundle === 'embedded') {
      return true;
    }
    currentVersion = parseInt(currentVersion);
  } catch (error1) {
    e = error1;
    return false;
  }
  return currentVersion < newVersion;
};

sys.bundle.dir = function(bundleVersion) {
  if (bundleVersion == null) {
    bundleVersion = 'embedded';
  }
  return "bundle_" + bundleVersion;
};

sys.bundle.extractTarBundle = function(filename, bundleVersion, options) {
  var bundleDir, error, multiFile, success;
  success = options.success, error = options.error;
  bundleDir = sys.bundle.dir(bundleVersion);
  multiFile = new MultiFile();
  multiFile.onerror = error;
  if (!sys.geo.Filesystem.apiSupported()) {
    if (typeof multiFile.onerror === "function") {
      multiFile.onerror();
    }
    return;
  }
  multiFile.onload = function() {
    var asyncTasks, file, i, len, onError, onSuccess, processFile, ref, results, wasError;
    this.files = (function() {
      var i, len, ref, results;
      ref = this.files;
      results = [];
      for (i = 0, len = ref.length; i < len; i++) {
        file = ref[i];
        if (!file.filename.endsWith(sys.geo.Filesystem.path_separator)) {
          results.push(file);
        }
      }
      return results;
    }).call(this);
    asyncTasks = this.files.length;
    wasError = this.files.length <= 0;
    if (wasError) {
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.error === "function") {
          console.error("Error during extraction from " + filename);
        }
      }
      if (typeof multiFile.onerror === "function") {
        multiFile.onerror();
      }
      return;
    }
    onSuccess = function() {
      --asyncTasks;
      if (asyncTasks <= 0) {
        if (!wasError) {
          if (typeof success === "function") {
            success(bundleVersion);
          }
        }
        if (wasError) {
          return typeof multiFile.onerror === "function" ? multiFile.onerror() : void 0;
        }
      }
    };
    onError = function(error) {
      wasError = true;
      error = JSON.stringify(error);
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.log === "function") {
          console.log("Error " + error);
        }
      }
      --asyncTasks;
      if (asyncTasks <= 0) {
        return typeof multiFile.onerror === "function" ? multiFile.onerror() : void 0;
      }
    };
    processFile = function(file) {
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.log === "function") {
          console.log(file.filename);
        }
      }
      return sys.geo.Filesystem.saveAsBinary((bundleDir + "/") + file.filename, file.data, {
        success: onSuccess,
        error: onError
      });
    };
    ref = this.files;
    results = [];
    for (i = 0, len = ref.length; i < len; i++) {
      file = ref[i];
      results.push(processFile(file));
    }
    return results;
  };
  if (typeof console !== "undefined" && console !== null) {
    if (typeof console.log === "function") {
      console.log("Unpacking " + filename + " to " + bundleDir);
    }
  }
  return multiFile.load(filename);
};

sys.bundle.downloadBundleByInfoUrl = function(currentVersionInfo, infoUrl, options) {
  var error, jsonReceived, queryParams, sameVersion, success;
  error = options.error, success = options.success, sameVersion = options.sameVersion;
  jsonReceived = function(downloadedJson) {
    var downloadError, downloadSuccess;
    downloadedJson = JSON.parse(downloadedJson);
    options = {
      success: function() {
        if (typeof success === "function") {
          success(downloadedJson.version.bundle);
        }
        return typeof console !== "undefined" && console !== null ? typeof console.log === "function" ? console.log("Bundle " + downloadedJson.version.bundle + " saved") : void 0 : void 0;
      },
      error: error
    };
    downloadError = function() {
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.error === "function") {
          console.error("Error during download of " + downloadedJson.url);
        }
      }
      return typeof error === "function" ? error() : void 0;
    };
    downloadSuccess = function(fileContent) {
      var filename;
      if (downloadedJson.md5 !== SparkMD5.ArrayBuffer.hash(fileContent)) {
        if (typeof console !== "undefined" && console !== null) {
          if (typeof console.error === "function") {
            console.error('Downloaded bundle md5 differs from update info');
          }
        }
        if (typeof error === "function") {
          error();
        }
        return;
      }
      filename = sys.bundle.dir(downloadedJson.version.bundle) + '.tar';
      return sys.geo.Filesystem.saveAsBinary(filename, fileContent, options);
    };
    if (!sys.bundle.canUpdateWithVersion(currentVersionInfo, downloadedJson != null ? downloadedJson.version : void 0)) {
      return typeof sameVersion === "function" ? sameVersion() : void 0;
    }
    return sys.xhr.getArrayBuffer(downloadedJson.url, downloadSuccess, downloadError);
  };
  queryParams = "core=" + (encodeURIComponent(currentVersionInfo.core)) + "&bundle=" + (encodeURIComponent(currentVersionInfo.bundle));
  return sys.xhr.getJson(infoUrl + "?" + queryParams, jsonReceived);
};

sys.bundle.extractCoreVersion = function(appVersion) {
  var ref, ref1;
  return appVersion != null ? (ref = appVersion.version) != null ? typeof ref.match === "function" ? (ref1 = ref.match(/.+\.(\d+)\..+/)) != null ? ref1[1] : void 0 : void 0 : void 0 : void 0;
};

sys.bundle.versionFile = function(appVersion) {
  return "version." + appVersion.version;
};

sys.bundle.saveVersionInfo = function(appVersion, callback) {
  var options, versionFile;
  versionFile = sys.bundle.versionFile(appVersion);
  options = {
    success: callback,
    error: callback
  };
  return sys.geo.Filesystem.saveAsText(versionFile, JSON.stringify(appVersion), options);
};

sys.bundle.getVersionInfo = function(appVersion, callback) {
  var fallbackVersion, versionFile;
  if (!sys.geo.Filesystem.apiSupported()) {
    return callback(appVersion);
  }
  if (appVersion != null) {
    appVersion.core = sys.bundle.extractCoreVersion(appVersion);
  }
  versionFile = sys.bundle.versionFile(appVersion);
  fallbackVersion = function() {
    sys.geo.Filesystem.saveAsText(versionFile, JSON.stringify(appVersion));
    return callback(appVersion);
  };
  return sys.geo.Filesystem.getFileInDataDir(versionFile, {
    success: function() {
      return sys.geo.Filesystem.readAsText(versionFile, {
        success: function(content) {
          var versionInfo;
          versionInfo = JSON.parse(content);
          return callback(versionInfo);
        },
        error: fallbackVersion
      });
    },
    error: fallbackVersion
  });
};

sys.bundle.updateIfNeeded = function(onUpdated, sameVersion) {
  var ref, ref1;
  if (!((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.getAppVersion) != null ? ref.getVersionNumber : void 0 : void 0) && (typeof cordova !== "undefined" && cordova !== null ? (ref1 = cordova.getAppVersion) != null ? ref1.getVersionCode : void 0 : void 0))) {
    return typeof sameVersion === "function" ? sameVersion() : void 0;
  }
  return cordova.getAppVersion.getVersionNumber().then(function(version) {
    return cordova.getAppVersion.getVersionCode().then(function(code) {
      return {
        version: version,
        code: code
      };
    }).then(function(appVersion) {
      return sys.bundle.getVersionInfo(appVersion, function(versionInfo) {
        var bundleUpdateInfo, currentBundleVersion, options;
        if (versionInfo.bundle == null) {
          versionInfo.bundle = 'embedded';
        }
        currentBundleVersion = {
          core: versionInfo.core,
          bundle: versionInfo.bundle
        };
        options = {
          sameVersion: sameVersion,
          success: function(bundleVersion) {
            var bundleDir;
            bundleDir = sys.bundle.dir(bundleVersion);
            options = {
              error: function() {
                return typeof console !== "undefined" && console !== null ? typeof console.error === "function" ? console.error("Couldn't get " + bundleDir + ".tar") : void 0 : void 0;
              },
              success: function(file) {
                var filename;
                filename = file.toURL();
                options = {
                  success: function(bundleVersion) {
                    if (versionInfo.bundle === bundleVersion) {
                      return typeof onUpdated === "function" ? onUpdated() : void 0;
                    }
                    versionInfo.bundle = bundleVersion;
                    return sys.bundle.saveVersionInfo(versionInfo, onUpdated);
                  },
                  error: function() {
                    return typeof console !== "undefined" && console !== null ? typeof console.error === "function" ? console.error("Couldn't extract " + filename) : void 0 : void 0;
                  }
                };
                return sys.bundle.extractTarBundle(filename, bundleVersion, options);
              }
            };
            return sys.geo.Filesystem.getFileInDataDir(bundleDir + ".tar", options);
          }
        };
        bundleUpdateInfo = sys.bundle.updateInfo;
        if (typeof console !== "undefined" && console !== null) {
          if (typeof console.log === "function") {
            console.log("Read version info by URL " + (bundleUpdateInfo != null ? bundleUpdateInfo.url : void 0));
          }
        }
        if ((bundleUpdateInfo != null ? bundleUpdateInfo.url : void 0) == null) {
          return options != null ? typeof options.error === "function" ? options.error() : void 0 : void 0;
        }
        return sys.bundle.downloadBundleByInfoUrl(currentBundleVersion, bundleUpdateInfo.url, options);
      });
    });
  });
};

namespace('sys.modules');

sys.modules.registred = [];

sys.modules.critical = ['ngCordova'];

if (typeof ionic !== "undefined" && ionic !== null) {
  sys.modules.critical.push('ionic');
}

sys.modules.unique = function() {
  var i, j, len, len1, module, name, ref, ref1, results, unique, value;
  unique = {};
  ref = sys.modules.registred;
  for (i = 0, len = ref.length; i < len; i++) {
    module = ref[i];
    unique[module.name] = 1;
  }
  ref1 = sys.modules.critical;
  for (j = 0, len1 = ref1.length; j < len1; j++) {
    module = ref1[j];
    unique[module] = 1;
  }
  results = [];
  for (name in unique) {
    value = unique[name];
    results.push(name);
  }
  return results;
};

sys.modules.active = function() {
  var activated, active, available, i, j, len, len1, module, ref, unique;
  available = {};
  ref = sys.modules.registred;
  for (i = 0, len = ref.length; i < len; i++) {
    module = ref[i];
    available[module.name] = 1;
  }
  active = [].concat(sys.modules.critical);
  if (store.enabled) {
    activated = store.get('sys.modules.active');
    if (_.isArray(activated)) {
      active = active.concat(activated);
    }
  }
  active = (function() {
    var j, len1, results;
    results = [];
    for (j = 0, len1 = active.length; j < len1; j++) {
      module = active[j];
      if (available[module]) {
        results.push(module);
      }
    }
    return results;
  })();
  unique = {};
  for (j = 0, len1 = active.length; j < len1; j++) {
    module = active[j];
    unique[module] = 1;
  }
  return _.map(unique, function(_, module) {
    return module;
  });
};

sys.modules.activate = function(module) {
  var activated, isExsists;
  activated = store.get('sys.modules.active');
  if (!_.isArray(activated)) {
    store.remove('sys.modules.active');
    activated = [];
  }
  isExsists = _.find(activated, function(active) {
    return active === module;
  });
  if (!isExsists) {
    activated.push(module);
  }
  return store.set('sys.modules.active', activated);
};

sys.modules.deactivate = function(module) {
  var activated;
  activated = store.get('sys.modules.active');
  if (!_.isArray(activated)) {
    activated = [];
  }
  activated = _.filter(activated, function(active) {
    return active !== module;
  });
  return store.set('sys.modules.active', activated);
};

sys.modules.needBaseBundle = function(versionInfo, need, dontNeed) {
  if (!sys.geo.Filesystem.apiSupported()) {
    return dontNeed();
  }
  return sys.geo.Filesystem.getFileInDataDir(sys.bundle.dir(versionInfo.bundle) + '/modules/modules.min.js', {
    success: dontNeed,
    error: need
  });
};

sys.modules.js = function(version, success) {
  var onEntriesSuccess;
  onEntriesSuccess = function(entries) {
    var entry;
    return success((function() {
      var i, len, results;
      results = [];
      for (i = 0, len = entries.length; i < len; i++) {
        entry = entries[i];
        results.push(entry.toURL());
      }
      return results;
    })());
  };
  return onEntriesSuccess([
    {
      toURL: function() {
        return 'modules/modules.js';
      }
    }
  ]);
};

sys.modules.addjs = function(js) {
  var jses, uniques;
  uniques = {};
  if (store.enabled) {
    jses = store.get('sys.modules.js');
    if (!_.isArray(js)) {
      jses = [];
    }
    jses.push(js);
    _.each(jses, function(js) {
      return uniques[js] = 1;
    });
  }
  jses = _.map(uniques, function(_, js) {
    return js;
  });
  return store.set('sys.modules.js', jses);
};

sys.modules.originalModuleFn = angular.module;

angular.module = function(module, requires, configFn) {
  var moduleName, moduleVersion;
  if (_.isArray(module)) {
    moduleName = module[0];
    moduleVersion = module[1];
  } else {
    moduleName = module;
    moduleVersion = '---';
  }
  if (moduleName !== '4g') {
    sys.modules.registred.push({
      name: moduleName,
      version: moduleVersion
    });
  }
  return sys.modules.originalModuleFn.call(this, moduleName, requires, configFn);
};

namespace('ru.geo.localization');

ru.geo.localization.supportedLocales = function() {
  return ruGeoLocalizationSupportedLocales();
};

ru.geo.localization.localeTranslations = function() {
  return ruGeoLocalizationLocaleTranslations();
};

ru.geo.localization.onlyCountry = function(locale) {
  return locale.toLowerCase().split('-')[0];
};

ru.geo.localization.cookieLocale = function() {
  var locale;
  locale = ru.geo.cookie.get('locale');
  if (locale != null) {
    return ru.geo.localization.onlyCountry(locale);
  }
};

ru.geo.localization.systemLocale = function() {
  var country;
  if (ru.geo.localization.localeTranslations()[navigator.language] != null) {
    return navigator.language;
  }
  country = ru.geo.localization.onlyCountry(navigator.language);
  if (ru.geo.localization.localeTranslations()[country] != null) {
    return country;
  }
  return ru.geo.localization.supportedLocales()[0];
};

ru.geo.localization.choosenLocale = function() {
  return ru.geo.localization.cookieLocale() || ru.geo.localization.systemLocale();
};

ru.geo.localization.Context = (function() {
  var makePluralIndexFunction;

  makePluralIndexFunction = function(plural_expr) {
    eval('var pluralIndexFn = function (n) { return ' + plural_expr + '; }');
    return pluralIndexFn;
  };

  Context.prototype.setPoContext = function(poContext1) {
    var base;
    this.poContext = poContext1;
    if ((base = this.poContext).locale == null) {
      base.locale = 'ru';
    }
    return this.pluralIndexFn = makePluralIndexFunction(this.poContext.plural_expr || '0');
  };

  function Context(poContext) {
    this.setPoContext(poContext);
  }

  Context.prototype.currentLocale = function() {
    return this.poContext.locale;
  };

  Context.prototype.localeTag = function() {
    if (!!this.poContext.localeTag) {
      return this.poContext.localeTag;
    }
    return 'ru-RU';
  };

  Context.prototype.translations = function(msgId) {
    var result, typeIsArray;
    result = this.poContext[msgId] || [msgId];
    typeIsArray = Array.isArray || function(value) {
      return {}.toString.call(value) === '[object Array]';
    };
    if (typeIsArray(result)) {
      return result;
    }
    return [result];
  };

  Context.prototype.pluralFormIndexForNumber = function(number) {
    return this.pluralIndexFn(number);
  };

  Context.prototype.getPluralFormForMsgId = function(msgId, number) {
    var pluralFormIndex, translations;
    translations = this.translations(msgId);
    pluralFormIndex = Math.min(this.pluralFormIndexForNumber(number), translations.length - 1);
    return translations[pluralFormIndex];
  };

  return Context;

})();

var slice = [].slice;

sys.bootstrap = function(version, baseUrl) {
  var fourGeoModuleName, initialized, localizationContextUrl, ref, ref1;
  fourGeoModuleName = '4g';
  angular.module(['sys.version', '1.0.0'], []).constant('version', version);
  if (typeof console !== "undefined" && console !== null) {
    if (typeof console.log === "function") {
      console.log('Modules:', sys.modules.unique());
    }
  }
  angular.module(fourGeoModuleName, sys.modules.unique()).filter('pluralFormForMessageWithNumber', [
    'ru.geo.localization.Context', function(localizationContext) {
      return function(input, number) {
        if (input == null) {
          input = '';
        }
        return localizationContext.getPluralFormForMsgId(input, number);
      };
    }
  ]).run([
    'T', '$log', '$rootScope', 'ru.geo.state.Service', 'ru.geo.mediaqueries.Service', function(T, log, $rootScope, stateService, mediaqueries) {
      var localeTag, ref, ref1;
      mediaqueries.bind();
      if ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.plugins) != null ? ref.Keyboard : void 0 : void 0) != null) {
        log.debug('Set cordova.plugins.Keyboard hideKeyboardAccessoryBar = false disableScroll = false');
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
        cordova.plugins.Keyboard.disableScroll(false);
      }
      if ((typeof cordova !== "undefined" && cordova !== null ? (ref1 = cordova.InAppBrowser) != null ? ref1.open : void 0 : void 0) != null) {
        delete window.open;
      }
      localeTag = T('localeTag');
      log.debug("Search locale: " + localeTag);
      $rootScope.rootState = stateService.state;
      return $rootScope.navbarEnterPressed = function(text) {
        return angular.extend(stateService.state.ru.geo.navbar, {
          searchQuery: stateService.state.ru.geo.navbar.searchText,
          date: new Date()
        });
      };
    }
  ]);
  if (typeof ionic !== "undefined" && ionic !== null) {
    angular.module(fourGeoModuleName).config([
      '$urlRouterProvider', '$compileProvider', '$ionicConfigProvider', 'fallbackUrlGenerator', function($urlRouterProvider, $compileProvider, $ionicConfigProvider, fallbackUrlGenerator) {
        $urlRouterProvider.otherwise(fallbackUrlGenerator);
        $compileProvider.debugInfoEnabled(false);
        $ionicConfigProvider.scrolling.jsScrolling(true);
        $ionicConfigProvider.navBar.alignTitle('center');
        return $ionicConfigProvider.tabs.position('top');
      }
    ]);
  }
  localizationContextUrl = ru.geo.localization.localeTranslations()[ru.geo.localization.choosenLocale()];
  if (baseUrl != null) {
    localizationContextUrl = baseUrl + "/" + localizationContextUrl;
  }
  if (localizationContextUrl == null) {
    localizationContextUrl = 'default-po-context.json';
  }
  initialized = false;
  return sys.xhr.getJson(((ref = window.Ionic) != null ? (ref1 = ref.WebView) != null ? ref1.convertFileSrc(localizationContextUrl) : void 0 : void 0) || localizationContextUrl, function(response) {
    var globalLocalizationContext, tFn;
    if (initialized) {
      return;
    }
    initialized = true;
    if (!response) {
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.warn === "function") {
          console.warn(localizationContextUrl + " is empty result");
        }
      }
      response = '{}';
    }
    globalLocalizationContext = new ru.geo.localization.Context(JSON.parse(response));
    tFn = function(phrase, n) {
      if (n == null) {
        return globalLocalizationContext.translations(phrase)[0];
      }
      return globalLocalizationContext.getPluralFormForMsgId(phrase, n);
    };
    angular.module(fourGeoModuleName).constant('ru.geo.localization.Context', globalLocalizationContext);
    angular.module(fourGeoModuleName).constant('T', tFn);
    angular.module(fourGeoModuleName).constant('Tn', tFn);
    return angular.bootstrap(document, [fourGeoModuleName]);
  });
};

document.addEventListener('DOMContentLoaded', function() {
  var appendBaseTagToHead, appendBaseUrl, applyDisableIosScrollingClass, bootstrap, onDeviceReady;
  appendBaseTagToHead = function(href) {
    var base, head;
    head = document.getElementsByTagName('head')[0];
    base = document.createElement('base');
    base.href = href;
    return head.appendChild(base);
  };
  appendBaseUrl = function(successCallback, path) {
    var onDataDirReady;
    onDataDirReady = function(dir) {
      appendBaseTagToHead(dir.toURL());
      return successCallback();
    };
    return sys.geo.Filesystem.getDirectoryInDataDir(path, {
      success: onDataDirReady,
      error: successCallback
    });
  };
  applyDisableIosScrollingClass = function() {
    return document.ontouchmove = function(event) {
      var isTouchMoveAllowed, target;
      isTouchMoveAllowed = true;
      target = event.target;
      while (target !== null) {
        if (target.classList && target.classList.contains('disable-ios-scrolling')) {
          isTouchMoveAllowed = false;
          break;
        }
        target = target.parentNode;
      }
      if (!isTouchMoveAllowed) {
        return event.preventDefault();
      }
    };
  };
  onDeviceReady = function() {
    var ref, ref1, version;
    if ((typeof ionic !== "undefined" && ionic !== null) && (typeof ionic !== "undefined" && ionic !== null ? ionic.Platform.isIOS() : void 0)) {
      applyDisableIosScrollingClass();
    }
    if ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.getAppVersion) != null ? ref.getVersionNumber : void 0 : void 0) && (typeof cordova !== "undefined" && cordova !== null ? (ref1 = cordova.getAppVersion) != null ? ref1.getVersionCode : void 0 : void 0)) {
      version = cordova.getAppVersion.getVersionNumber().then(function(version) {
        return cordova.getAppVersion.getVersionCode().then(function(code) {
          return {
            version: version,
            code: code
          };
        });
      });
      version.then(function(version) {
        return bootstrap(version);
      });
      if (version["catch"] == null) {
        version["catch"] = version.fail;
      }
      return version["catch"](function() {
        return bootstrap({});
      });
    } else {
      return bootstrap({});
    }
  };
  bootstrap = function(version) {
    return sys.modules.js(version, function(jsToLoad) {
      var baseUrl, loadScripts;
      if (typeof console !== "undefined" && console !== null) {
        if (typeof console.log === "function") {
          console.log('jsToLoad ' + JSON.stringify(jsToLoad));
        }
      }
      baseUrl = null;
      loadScripts = function(urls, success) {
        var head, ref, ref1, ref2, script, url;
        if (urls == null) {
          urls = [];
        }
        if (!_.isArray(urls) || _.isEmpty(urls)) {
          if (sys.geo.Filesystem.apiSupported()) {
            sys.bundle.getVersionInfo(version, function(versionInfo) {
              var ref, ref1;
              baseUrl = cordova.file.dataDirectory + sys.bundle.dir(versionInfo.bundle);
              return appendBaseUrl(success, ((ref = window.Ionic) != null ? (ref1 = ref.WebView) != null ? ref1.convertFileSrc(baseUrl) : void 0 : void 0) || baseUrl);
            });
            return;
          }
          return success();
        } else {
          ref = urls, url = ref[0], urls = 2 <= ref.length ? slice.call(ref, 1) : [];
          head = document.getElementsByTagName('head')[0];
          script = document.createElement('script');
          script.type = 'text/javascript';
          head.appendChild(script);
          if (script.readyState != null) {
            script.onreadystatechange = function() {
              if (script.readyState === 'loaded') {
                return loadScripts(urls, success);
              }
            };
          }
          script.onload = function() {
            return loadScripts(urls, success);
          };
          return script.src = ((ref1 = window.Ionic) != null ? (ref2 = ref1.WebView) != null ? ref2.convertFileSrc(url) : void 0 : void 0) || url;
        }
      };
      return loadScripts(jsToLoad, function() {
        return sys.bootstrap(version, baseUrl);
      });
    });
  };
  if (typeof cordova !== "undefined" && cordova !== null) {
    return document.addEventListener('deviceready', onDeviceReady, false);
  } else {
    return onDeviceReady();
  }
});

var base, base1, base2, base3,
  slice = [].slice;

if ((base = String.prototype).startsWith == null) {
  base.startsWith = function(s) {
    return this.slice(0, s.length) === s;
  };
}

if ((base1 = String.prototype).endsWith == null) {
  base1.endsWith = function(s) {
    return s === '' || this.slice(-s.length) === s;
  };
}

if ((base2 = String.prototype).join == null) {
  base2.join = function() {
    var parts, sep;
    sep = arguments[0], parts = 2 <= arguments.length ? slice.call(arguments, 1) : [];
    _.filter(parts, function(part) {
      return part != null;
    });
    return parts.join(sep);
  };
}

if ((base3 = Array.prototype).combine == null) {
  base3.combine = function(sep) {
    var part, regex, replaced;
    regex = new RegExp(sep + '$|^' + sep + '|^\\s+|\\s+$');
    replaced = (function() {
      var i, len, ref, results;
      ref = this;
      results = [];
      for (i = 0, len = ref.length; i < len; i++) {
        part = ref[i];
        if (!!part) {
          results.push(part.replace(regex, ''));
        }
      }
      return results;
    }).call(this);
    replaced = (function() {
      var i, len, results;
      results = [];
      for (i = 0, len = replaced.length; i < len; i++) {
        part = replaced[i];
        if (!!part) {
          results.push(part);
        }
      }
      return results;
    })();
    return replaced.join(sep);
  };
}

Array.prototype.partition = function(callback) {
  var i, index, item, len, negative, positive, ref, ref1;
  ref = [[], []], positive = ref[0], negative = ref[1];
  ref1 = this;
  for (index = i = 0, len = ref1.length; i < len; index = ++i) {
    item = ref1[index];
    (callback(item, index) ? positive : negative).push(item);
  }
  return [positive, negative];
};

Array.prototype.groupped = function(groupSize, groupCallback) {
  var group, i, key, len, ref;
  group = [];
  ref = this;
  for (i = 0, len = ref.length; i < len; i++) {
    key = ref[i];
    group.push(key);
    if (group.length >= groupSize) {
      groupCallback(group);
      group = [];
    }
  }
  if (group.length > 0) {
    return groupCallback(group);
  }
};

Array.prototype.takeWhile = function(callback) {
  var acc, i, item, len, ref;
  acc = [];
  ref = this;
  for (i = 0, len = ref.length; i < len; i++) {
    item = ref[i];
    if (!callback(item)) {
      return acc;
    }
    acc.push(item);
  }
};

Array.prototype.toMap = function() {
  var i, item, len, map, ref;
  map = {};
  ref = this;
  for (i = 0, len = ref.length; i < len; i++) {
    item = ref[i];
    map[item] = 1;
  }
  return map;
};

Array.prototype.filter = function(callback) {
  var i, item, len, ref, results;
  ref = this;
  results = [];
  for (i = 0, len = ref.length; i < len; i++) {
    item = ref[i];
    if (callback(item)) {
      results.push(item);
    }
  }
  return results;
};

Array.prototype.groupBy = function(field) {
  var hash, i, item, j, len, len1, ref, ref1;
  hash = {};
  ref = this;
  for (i = 0, len = ref.length; i < len; i++) {
    item = ref[i];
    if (item[field] != null) {
      hash[item[field]] = [];
    }
  }
  ref1 = this;
  for (j = 0, len1 = ref1.length; j < len1; j++) {
    item = ref1[j];
    if (item[field] != null) {
      hash[item[field]].push(item);
    }
  }
  return hash;
};

var slice = [].slice;

namespace('sys.geo');

sys.geo.Filesystem = (function() {
  function Filesystem() {}

  Filesystem.path_separator = '/';

  Filesystem.emptyFn = function() {};

  Filesystem.apiSupported = function() {
    var ref;
    return ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.file) != null ? ref.dataDirectory : void 0 : void 0) != null) && ((window.requestFileSystem != null) || (window.webkitRequestFileSystem != null)) && (window.resolveLocalFileSystemURL != null);
  };

  Filesystem.getEntitiesByExtension = function(extension, options) {
    var asyncTasks, collectFilesInDir, entries, error, path, recursively, regexp, success;
    path = options.path, success = options.success, error = options.error, recursively = options.recursively;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    if (recursively == null) {
      recursively = true;
    }
    if (path == null) {
      path = '';
    }
    entries = [];
    asyncTasks = 0;
    regexp = RegExp(".*\\." + extension + "$");
    collectFilesInDir = function(dir) {
      var dirReader, readEntries;
      asyncTasks++;
      dirReader = dir.createReader();
      readEntries = function() {
        return dirReader.readEntries(function(results) {
          var addToEntries, entry, i, len;
          if (!results.length) {
            asyncTasks--;
            if (asyncTasks <= 0) {
              return success(entries.sort());
            }
          } else {
            addToEntries = function(entry) {
              if (entry.isDirectory && recursively) {
                return collectFilesInDir(entry);
              } else {
                if (regexp.test(entry.name)) {
                  return entries.push(entry);
                }
              }
            };
            for (i = 0, len = results.length; i < len; i++) {
              entry = results[i];
              addToEntries(entry);
            }
            return readEntries();
          }
        });
      };
      return readEntries();
    };
    return sys.geo.Filesystem.getDirectoryInDataDir(path, {
      success: collectFilesInDir,
      error: error
    });
  };

  Filesystem.getDirectoryInDataDir = function(path, options) {
    var dirSucces, dirs, error, success;
    success = options.success, error = options.error;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    dirs = sys.geo.Filesystem.splitPath(path);
    dirSucces = function(dir) {
      var nextDir, ref;
      ref = dirs, nextDir = ref[0], dirs = 2 <= ref.length ? slice.call(ref, 1) : [];
      if (!!nextDir) {
        dir.getDirectory(nextDir, {
          create: true
        }, dirSucces, error);
        return;
      }
      return success(dir);
    };
    return sys.geo.Filesystem.getDataDir(dirSucces, error);
  };

  Filesystem.getFileInDataDir = function(path, options) {
    var dirs, error, file, i, onSuccess, ref, success;
    ref = sys.geo.Filesystem.splitPath(path), dirs = 2 <= ref.length ? slice.call(ref, 0, i = ref.length - 1) : (i = 0, []), file = ref[i++];
    success = options.success, error = options.error;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    onSuccess = function(dir) {
      return dir.getFile(file, {
        create: false
      }, success, error);
    };
    return sys.geo.Filesystem.getDirectoryInDataDir(dirs.join(sys.geo.Filesystem.path_separator), {
      success: onSuccess,
      error: error
    });
  };

  Filesystem.createBlob = function(array, blobType) {
    var BlobBuilder, blob, builder;
    if (array.base64Encoded != null) {
      return array;
    }
    try {
      blob = new Blob([array], {
        type: blobType
      });
    } catch (error1) {
      BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
      if (BlobBuilder) {
        builder = new BlobBuilder();
        builder.append(array);
        blob = builder.getBlob();
      } else {
        blob = array;
      }
    }
    return blob;
  };

  Filesystem.saveAs = function(filename, data, options) {
    var blobType, dirs, error, file, i, ref, saveToDir, success;
    blobType = options.blobType, success = options.success, error = options.error;
    if (blobType == null) {
      blobType = 'text/plain';
    }
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    ref = sys.geo.Filesystem.splitPath(filename), dirs = 2 <= ref.length ? slice.call(ref, 0, i = ref.length - 1) : (i = 0, []), file = ref[i++];
    saveToDir = function(dir) {
      var saveData;
      saveData = function(fileEntity) {
        var write;
        write = function(writer) {
          writer.onwriteend = function() {
            writer.onwriteend = success;
            return writer.write(sys.geo.Filesystem.createBlob(data, blobType));
          };
          writer.onerror = error;
          return writer.truncate(0);
        };
        return fileEntity.createWriter(write, error);
      };
      return dir.getFile(file, {
        create: true
      }, saveData, error);
    };
    return sys.geo.Filesystem.getDirectoryInDataDir(dirs.join(sys.geo.Filesystem.path_separator), {
      success: saveToDir,
      error: error
    });
  };

  Filesystem.saveAsText = function(filename, data, options) {
    return sys.geo.Filesystem.saveAs(filename, data, {
      blobType: 'text/plain',
      success: options != null ? options.success : void 0,
      error: options != null ? options.error : void 0
    });
  };

  Filesystem.saveAsBinary = function(filename, data, options) {
    return sys.geo.Filesystem.saveAs(filename, data.buffer || data, {
      blobType: 'application/octet-stream',
      success: options != null ? options.success : void 0,
      error: options != null ? options.error : void 0
    });
  };

  Filesystem.readAsDataUrlFn = function(reader, fileObject) {
    return reader.readAsDataURL(fileObject);
  };

  Filesystem.readAsTextFn = function(reader, fileObject) {
    return reader.readAsText(fileObject);
  };

  Filesystem.readAs = function(filename, readFn, options) {
    var dirs, error, file, i, readFileInDir, ref, success;
    success = options.success, error = options.error;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    ref = sys.geo.Filesystem.splitPath(filename), dirs = 2 <= ref.length ? slice.call(ref, 0, i = ref.length - 1) : (i = 0, []), file = ref[i++];
    readFileInDir = function(dir) {
      var onFileEntrySuccess;
      onFileEntrySuccess = function(fileEntity) {
        var onFileSuccess;
        onFileSuccess = function(fileObj) {
          var reader;
          reader = new FileReader;
          reader.onloadend = function(e) {
            return success(this.result);
          };
          reader.onerror = error;
          return readFn(reader, fileObj);
        };
        return fileEntity.file(onFileSuccess, error);
      };
      return dir.getFile(file, {
        create: false
      }, onFileEntrySuccess, error);
    };
    return sys.geo.Filesystem.getDirectoryInDataDir(dirs.join(sys.geo.Filesystem.path_separator), {
      success: readFileInDir,
      error: error
    });
  };

  Filesystem.readAsText = function(filename, options) {
    return sys.geo.Filesystem.readAs(filename, sys.geo.Filesystem.readAsTextFn, {
      success: options != null ? options.success : void 0,
      error: options != null ? options.error : void 0
    });
  };

  Filesystem.readAsDataUrl = function(filename, options) {
    return sys.geo.Filesystem.readAs(filename, sys.geo.Filesystem.readAsDataUrlFn, {
      success: options != null ? options.success : void 0,
      error: options != null ? options.error : void 0
    });
  };

  Filesystem.getDataDir = function(success, error) {
    var onInitFs, ref, ref1, ref2, url;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    if ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.file) != null ? ref.dataDirectory : void 0 : void 0) != null) {
      url = window.resolveLocalFileSystemURL(cordova.file.dataDirectory, success, error);
      return ((ref1 = window.Ionic) != null ? (ref2 = ref1.WebView) != null ? ref2.convertFileSrc(url) : void 0 : void 0) || url;
    }
    onInitFs = function(fs) {
      return success(fs.root);
    };
    if (window.requestFileSystem == null) {
      window.requestFileSystem = window.webkitRequestFileSystem;
    }
    return window.requestFileSystem(window.TEMPORARY, 1024 * 1024, onInitFs, error);
  };

  Filesystem.removeDirRecursively = function(path, options) {
    var error, success;
    if (options == null) {
      options = {};
    }
    success = options.success, error = options.error;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    return sys.geo.Filesystem.getDirectoryInDataDir(path, {
      success: function(dir) {
        return dir.removeRecursively(success, error);
      },
      error: error
    });
  };

  Filesystem.removeFile = function(path, options) {
    var error, success;
    if (options == null) {
      options = {};
    }
    success = options.success, error = options.error;
    if (success == null) {
      success = sys.geo.Filesystem.emptyFn;
    }
    if (error == null) {
      error = sys.geo.Filesystem.emptyFn;
    }
    return sys.geo.Filesystem.getFileInDataDir(path, {
      success: function(file) {
        return file.remove(success, error);
      },
      error: error
    });
  };

  Filesystem.splitPath = function(filename) {
    return filename.split(sys.geo.Filesystem.path_separator);
  };

  Filesystem.addPathComponent = function(path, component) {
    if (!path.endsWith(sys.geo.Filesystem.path_separator)) {
      path += sys.geo.Filesystem.path_separator;
    }
    if (component.startsWith(sys.geo.Filesystem.path_separator)) {
      component = component.slice(1);
    }
    return path += component;
  };

  Filesystem.resourceUrl = function(path) {
    var ref;
    if ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.file) != null ? ref.applicationDirectory : void 0 : void 0) != null) {
      return [cordova.file.applicationDirectory, 'www/resources', path].combine('/');
    } else {
      return ['resources', path].combine('/');
    }
  };

  return Filesystem;

})();

namespace('ru.geo.patch');

ru.geo.patch.softKeyboardPatchFor2x = function(value) {
  var el;
  if (document.activeElement.tagName.toLowerCase() !== 'input') {
    return;
  }
  el = angular.element(document.activeElement);
  el.val(el.val() + value);
  return el.triggerHandler('input');
};

namespace('ru.geo.app.config');

ru.geo.app.config.params = (function() {
  var params, ref, search;
  search = (typeof document !== "undefined" && document !== null ? (ref = document.location) != null ? ref.search : void 0 : void 0) || '';
  params = {};
  search.replace(new RegExp('([^?=&]+)(=([^&]*))?', 'g'), function($0, $1, $2, $3) {
    return params[$1] = $3;
  });
  return params;
})();

angular.module(['ru.geo.app.config', '1.0.0'], []).constant('dom7', Dom7).constant('app-name', 'Japanese_Food').constant('bundle-id', 'ru.geo.ppmobile.kidospb').constant('app-version', '1.0.2624').constant('framework7-version', '4.0.6').constant('app-id', (function() {
  var appId;
  if (!!ru.geo.app.config.params['app-id']) {
    appId = decodeURIComponent(ru.geo.app.config.params['app-id']);
  }
  return appId || '1994704717';
})()).constant('app-platform', {
  isIos: 'ios' === 'ios',
  isAndroid: 'ios' === 'android'
}).constant('app-platform-name', 'ios').constant('custom-header', 'X-REQUEST-DATA').constant('sentry-dsn', 'https://00b00e04eaeb4d50a75cfafd27af307b@sentry.4mobile.me/9').constant('pushRegistrationOptions', {
  baseUrl: '/rest/push'
}).constant('pushServiceOptions', {
  platform: 'FCM',
  android: {
    senderID: '164298406024'
  },
  ios: {
    alert: 'true',
    badge: 'true',
    sound: 'true'
  }
}).constant('ajax-timeout', 20000).constant('params', ru.geo.app.config.params).constant('index-page', (function() {
  var url;
  if (!!ru.geo.app.config.params['url']) {
    url = decodeURIComponent(ru.geo.app.config.params['url']);
  }
  return url || 'https://4mobile-app.ru/c/1994704717/';
})()).constant('ui-test-enabled', false).constant('template-start-symbol', '{{').constant('template-end-symbol', '}}');

namespace('sys.catch');

sys["catch"].Controller = (function() {
  Controller.$inject = ['error', 'T'];

  Controller.prototype.functionRegex = /function (.{1,})\(/;

  function Controller(error, T) {
    var constructorName, ref, ref1, stack;
    this.error = error;
    this.error || (this.error = new Error('Unknown error'));
    if (typeof console.log === "function") {
      console.log(this.error);
    }
    this.title = T('Произошла ошибка');
    this.wifiText = T('Не удалось запросить данный по сети, проверьте наличие подключения');
    this.positionText = T('Не удалось определить ваше местоположение, попробуйте включить wifi или gps');
    this.unknownText = T('Пожалуйста отправьте эту информацию разработчикам');
    this.type = 'unknown';
    constructorName = this.getConstructorName(this.error);
    this.log = constructorName === 'PositionError' ? (this.type = 'position', T("Unable to get geoposition, cause: " + this.error.message)) : this.error instanceof Error && (this.error.stack != null) ? (stack = this.error.stack.replace(/^[^\(]+?[\n$]/gm, '').replace(/^\s+at\s+/gm, '').replace(/^Object.<anonymous>\s*\(/gm, '{anonymous}()@').split('\n'), this.error.message + ", cause: " + stack) : ((((ref = this.error) != null ? ref.status : void 0) != null) && (((ref1 = this.error) != null ? ref1.statusText : void 0) != null) ? this.type = 'internet' : void 0, JSON.stringify(this.error));
  }

  Controller.prototype.getConstructorName = function(obj) {
    var results;
    results = this.functionRegex.exec(obj.constructor.toString());
    if (results && results.length > 1) {
      return results[1];
    } else {
      return '';
    }
  };

  return Controller;

})();

namespace('sys.catch');

angular.module(['sys.catch', '1.0.0'], []);

if (typeof ionic !== "undefined" && ionic !== null) {
  angular.module('sys.catch').controller('sys.catch.Controller', sys["catch"].Controller).config([
    '$stateProvider', function($stateProvider) {
      return $stateProvider.state('menu.catch', {
        url: '/catch',
        title: 'error',
        views: {
          'menuContent': {
            templateUrl: 'catch/catch.html',
            controller: 'sys.catch.Controller as controller'
          }
        },
        resolve: {
          error: function() {
            return this.self.error;
          }
        }
      });
    }
  ]);
}

namespace('sys.connection');

sys.connection.Service = (function() {
  Service.$inject = ['$rootScope'];

  function Service(rootScope) {
    this.rootScope = rootScope;
    if (this._isConnected()) {
      this.switchOnline();
    } else {
      this.switchOffline();
    }
  }

  Service.prototype.watchConnection = function() {
    document.addEventListener('offline', (function(_this) {
      return function() {
        return _this.switchOffline();
      };
    })(this));
    return document.addEventListener('online', (function(_this) {
      return function() {
        return _this.switchOnline();
      };
    })(this));
  };

  Service.prototype.switchOffline = function() {
    if (!this.isOnline) {
      return;
    }
    return this.rootScope.$applyAsync((function(_this) {
      return function() {
        return _this.isOnline = false;
      };
    })(this));
  };

  Service.prototype.switchOnline = function() {
    if (this.isOnline) {
      return;
    }
    return this.rootScope.$applyAsync((function(_this) {
      return function() {
        return _this.isOnline = true;
      };
    })(this));
  };

  Service.prototype._isConnected = function() {
    if (!((typeof Connection !== "undefined" && Connection !== null) && ((typeof navigator !== "undefined" && navigator !== null ? navigator.connection : void 0) != null))) {
      return true;
    }
    return navigator.connection.type !== Connection.NONE;
  };

  return Service;

})();

namespace('sys.connection');

angular.module(['sys.connection', '1.0.0'], []).service('$connection', sys.connection.Service).run([
  '$connection', function($connection) {
    return $connection.watchConnection();
  }
]);

var slice = [].slice;

namespace('ru.geo.state');

ru.geo.state.Service = (function() {
  function Service(version, state) {
    this.state = state;
    this.state.version = version;
  }

  Service.prototype["for"] = function(path) {
    var i, name, pre, ref, ref1;
    ref1 = path.split('.'), pre = 2 <= ref1.length ? slice.call(ref1, 0, i = ref1.length - 1) : (i = 0, []), name = ref1[i++];
    ref = namespace(pre.join('.'), this.state);
    ref[name] || (ref[name] = {});
    return ref[name];
  };

  return Service;

})();

namespace('ru.geo.state');

ru.geo.state.Factory = function(statePath) {
  return [
    'ru.geo.state.Service', statePath, function(stateService, statePath) {
      return stateService["for"](statePath);
    }
  ];
};

var slice = [].slice;

namespace('ru.geo.state');

ru.geo.state.Provider = (function() {
  function Provider() {}

  Provider.prototype.initialState = {};

  Provider.prototype.state = function(path, data) {
    var i, name, pre, ref, ref1;
    ref1 = path.split('.'), pre = 2 <= ref1.length ? slice.call(ref1, 0, i = ref1.length - 1) : (i = 0, []), name = ref1[i++];
    ref = namespace(pre.join('.'), this.initialState);
    return ref[name] = data;
  };

  Provider.prototype.$get = [
    'version', function(version) {
      return new ru.geo.state.Service(version, this.initialState);
    }
  ];

  return Provider;

})();

namespace('ru.geo.state');

angular.module(['ru.geo.state', '1.0.0'], []).provider('ru.geo.state.Service', ru.geo.state.Provider);

namespace('ru.geo.location.helper');

ru.geo.location.helper.LatLon = (function() {
  function LatLon() {}

  LatLon.prototype.distanceInMeters = function(fLat, fLon, sLat, sLon) {
    var R, a, c, d, dLat, dLon;
    R = 6378.137;
    dLat = (sLat - fLat) * Math.PI / 180;
    dLon = (sLon - fLon) * Math.PI / 180;
    a = Math.sin(dLat / 2) * Math.sin(dLat / 2) + Math.cos(fLat * Math.PI / 180) * Math.cos(sLat * Math.PI / 180) * Math.sin(dLon / 2) * Math.sin(dLon / 2);
    c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1 - a));
    d = R * c;
    return d * 1000;
  };

  return LatLon;

})();

var bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

namespace('ru.geo.location');

ru.geo.location.Service = (function() {
  Service.$inject = ['$http', '$q', '$window', '$cordovaBackgroundGeolocation', '$cordovaGeolocation', 'ru.geo.location.TIMEOUT', 'ru.geo.location.UPDATE_TIMEOUT', '$log', '$rootScope', 'ru.geo.state.Service', 'ru.geo.location.state.path'];

  Service.prototype.ENABLE_BACKGROUND_GEOLOCATION = false;

  Service.prototype.options = {
    desiredAccuracy: 20,
    stationaryRadius: 20,
    debug: false,
    distanceFilter: 30,
    url: '',
    params: {},
    headers: {},
    locationTimeout: 5000,
    notificationTitle: 'Background tracking',
    notificationText: 'ENABLED',
    activityType: 'AutomotiveNavigation',
    maximumAge: 0,
    frequency: 10000,
    timeout: 2e308,
    enableHighAccuracy: true
  };

  function Service(http, q, window, backgroundGeolocation, geolocation, timeout, updateTimeout, log, rootScope, stateSerivce, statePath) {
    this.http = http;
    this.q = q;
    this.window = window;
    this.backgroundGeolocation = backgroundGeolocation;
    this.geolocation = geolocation;
    this.timeout = timeout;
    this.updateTimeout = updateTimeout;
    this.log = log;
    this.rootScope = rootScope;
    this.stateSerivce = stateSerivce;
    this.statePath = statePath;
    this.updatePosition = bind(this.updatePosition, this);
    this.options.timeout = this.timeout;
    this.options.locationTimeout = this.timeout;
    this.updatedAt = 0;
    this.isLocationFound = false;
    this.getGpsPosition().then((function(_this) {
      return function() {
        return _this.isLocationFound = true;
      };
    })(this));
  }

  Service.prototype.getGeoPosition = function() {
    var latlon;
    latlon = this.stateSerivce["for"](this.statePath).latlon;
    if (latlon.length === 2) {
      return this.q.when({
        lat: latlon[0],
        lon: latlon[1]
      });
    }
    return this.getGpsPosition().then((function(_this) {
      return function(gps) {
        _this.rootScope.$applyAsync(function() {
          if (latlon.length === 2) {
            return;
          }
          latlon[0] = gps.lat;
          return latlon[1] = gps.lon;
        });
        if (latlon.length === 2) {
          return {
            lat: latlon[0],
            lon: latlon[1]
          };
        } else {
          return gps;
        }
      };
    })(this));
  };

  Service.prototype.setGeoPosition = function(position) {
    var latlon;
    if (!((position != null ? position.lat : void 0) && (position != null ? position.lon : void 0))) {
      return;
    }
    latlon = this.stateSerivce["for"](this.statePath).latlon;
    latlon[0] = position.lat;
    return latlon[1] = position.lon;
  };

  Service.prototype.getGpsPosition = function() {
    var lat, lon, ref, ref1, ref2, ref3;
    lat = (ref = this.geoposition) != null ? (ref1 = ref.coords) != null ? ref1.latitude : void 0 : void 0;
    lon = (ref2 = this.geoposition) != null ? (ref3 = ref2.coords) != null ? ref3.longitude : void 0 : void 0;
    if ((lat != null) && (lon != null) && Date.now() - this.updatedAt < this.updateTimeout) {
      return this.q.when({
        lat: lat,
        lon: lon
      });
    }
    return this.geolocation.getCurrentPosition(this.options).then((function(_this) {
      return function(position) {
        _this.updatePosition(position);
        return {
          lat: position.coords.latitude,
          lon: position.coords.longitude
        };
      };
    })(this))["catch"]((function(_this) {
      return function(error) {
        if ((lat != null) && (lon != null)) {
          return {
            lat: lat,
            lon: lon
          };
        } else {
          return _this.q.reject(error);
        }
      };
    })(this));
  };

  Service.prototype.watchGeoPosition = function(watcher) {
    return this.rootScope.$watchCollection(((function(_this) {
      return function() {
        return _this.stateSerivce["for"](_this.statePath).latlon;
      };
    })(this)), function(latlon) {
      if (latlon.length !== 2) {
        return;
      }
      return watcher({
        lat: latlon[0],
        lon: latlon[1]
      });
    });
  };

  Service.prototype.watchGpsPosition = function(watcher) {
    return this.rootScope.$watchCollection(((function(_this) {
      return function() {
        var ref;
        return (ref = _this.geoposition) != null ? ref.coords : void 0;
      };
    })(this)), function(coords) {
      if (coords == null) {
        return;
      }
      return watcher({
        lat: coords.latitude,
        lon: coords.longitude,
        gps: coords
      });
    });
  };

  Service.prototype.watch = function() {
    return this.log.error("Method 'watch' is removed from locationSerivce");
  };

  Service.prototype.start = function() {
    var deferred, location, ref, watch, watchError, watchSuccess;
    this.log.debug('Start watching for geolocation');
    if ((((ref = this.window) != null ? ref.plugins : void 0) != null) && this.ENABLE_BACKGROUND_GEOLOCATION) {
      location = this.backgroundGeolocation.configure(this.options);
      return location.then((function(_this) {
        return function(positon) {
          return _this.updatePosition(position);
        };
      })(this));
    } else {
      deferred = this.q.defer();
      watchSuccess = (function(_this) {
        return function(position) {
          _this.updatePosition(position);
          return deferred.resolve(position);
        };
      })(this);
      watchError = (function(_this) {
        return function(error) {
          _this.log.error("Position detection error (code: " + (error != null ? error.code : void 0) + ", message: \"" + (error != null ? error.message : void 0) + "\")");
          return deferred.reject();
        };
      })(this);
      watch = this.geolocation.watchPosition(this.options);
      watch.then(null, watchError, watchSuccess);
      return deferred.promise;
    }
  };

  Service.prototype.updatePosition = function(position) {
    this.geoposition = position;
    return this.updatedAt = Date.now();
  };

  return Service;

})();

namespace('ru.geo.location');

angular.module('ru.geo.location', ['ru.geo.state', 'ngCordova']).service('ru.geo.location.Service', ru.geo.location.Service).service('ru.geo.location.helper.LatLon', ru.geo.location.helper.LatLon).constant('ru.geo.location.TIMEOUT', 3000).constant('ru.geo.location.UPDATE_TIMEOUT', 60000).constant('ru.geo.location.state.path', 'ru.geo.location').config([
  'ru.geo.state.ServiceProvider', 'ru.geo.location.state.path', function(stateProvider, statePath) {
    return stateProvider.state(statePath, {
      latlon: []
    });
  }
]);

namespace('ru.geo.mediaqueries');

ru.geo.mediaqueries.Service = (function() {
  Service.$inject = ['$log', '$rootScope', '$timeout', 'ru.geo.mediaqueries.state', 'mediaevent', 'ru.geo.mediaqueries.threshold'];

  function Service(log, rootScope, timeout, state, event, threshold) {
    this.log = log;
    this.rootScope = rootScope;
    this.timeout = timeout;
    this.state = state;
    this.event = event;
    this.threshold = threshold;
  }

  Service.prototype.bind = function() {
    this.addEvent(window, 'resize', (function(_this) {
      return function() {
        return _this.updateWidth();
      };
    })(this));
    return this.updateWidth();
  };

  Service.prototype.addEvent = function(object, type, callback) {
    if (object === null || typeof object === 'undefined') {
      return;
    }
    if (object.addEventListener) {
      return object.addEventListener(type, callback, false);
    } else if (object.attachEvent) {
      return object.attachEvent('on' + type, callback);
    } else {
      return object['on' + type] = callback;
    }
  };

  Service.prototype.width = function() {
    return window.innerWidth;
  };

  Service.prototype.height = function() {
    return window.innerHeight;
  };

  Service.prototype.updateWidth = function() {
    var fn, newWidth, oldWidth;
    newWidth = this.width();
    oldWidth = this.oldWidth || 0;
    if (Math.abs(newWidth - oldWidth) < this.threshold) {
      return;
    }
    if (this.cancel) {
      this.timeout.cancel(this.cancel);
      delete this.cancel;
    }
    this.oldWidth = newWidth;
    fn = (function(_this) {
      return function() {
        _this.state.$screen = newWidth;
        _this.state.$wideScreen = _this.state.$screen > 768;
        _this.log.info("[mediaqueries] wideScreen: " + _this.state.$wideScreen + ", screen: " + _this.state.$screen);
        return _this.rootScope.$broadcast(_this.event, _this.state);
      };
    })(this);
    return this.cancel = this.timeout(fn, 100);
  };

  return Service;

})();

namespace('ru.geo.mediaqueries');

angular.module(['ru.geo.mediaqueries', '1.0.0'], ['ru.geo.state']).service('ru.geo.mediaqueries.Service', ru.geo.mediaqueries.Service).constant('mediaevent', 'ru.geo.mediaqueries.event.media.changed').constant('ru.geo.mediaqueries.state.path', 'ru.geo.mediaqueries').constant('ru.geo.mediaqueries.threshold', 40).factory('ru.geo.mediaqueries.state', ru.geo.state.Factory('ru.geo.mediaqueries.state.path')).config([
  'ru.geo.state.ServiceProvider', 'ru.geo.mediaqueries.state.path', function(stateProvider, statePath) {
    return stateProvider.state(statePath, {
      '$wideScreen': false
    });
  }
]);

namespace('sys.launch.external');

sys.launch.external.Directive = function(log) {
  return {
    restrict: 'A',
    link: function(scope, element, attrs) {
      return element.on('click', function(e) {
        var href, ref, target;
        href = attrs.href;
        target = attrs.target || '_blank';
        if (element.hasClass('external')) {
          return;
        }
        if ((typeof cordova !== "undefined" && cordova !== null ? (ref = cordova.InAppBrowser) != null ? ref.open : void 0 : void 0) != null) {
          target = '_system';
          log.info("[launch.external] link (" + href + "), target (" + target + "), method (inappbrowser)");
          cordova.InAppBrowser.open(href, target);
        } else {
          log.info("[launch.external] link (" + href + "), target (" + target + "), method (window.open)");
          window.open(href, target);
        }
        e.preventDefault();
        e.stopPropagation();
        return false;
      });
    }
  };
};

sys.launch.external.Directive.$inject = ['$log'];

namespace('sys.launch');

angular.module(['sys.launch.external', '1.0.0'], []).directive('launchExternal', sys.launch.external.Directive);

namespace('ru.geo.localstorage');

ru.geo.localstorage.Service = (function() {
  Service.prototype.store = {};

  function Service() {
    var key, ref, val;
    this.impl = store || (typeof window !== "undefined" && window !== null ? window.store : void 0);
    if (!((this.impl != null) && (this.impl.enabled != null))) {
      return;
    }
    ref = this.impl;
    for (key in ref) {
      val = ref[key];
      this[key] = val;
    }
  }

  Service.prototype.get = function(key) {
    return this.store[key];
  };

  Service.prototype.set = function(key, val) {
    return this.store[key] = val;
  };

  Service.prototype.remove = function() {
    return delete this.store[key];
  };

  Service.prototype.clear = function() {
    return this.store = {};
  };

  Service.prototype.getAll = function() {
    var key, ref, results, val;
    ref = this.store;
    results = [];
    for (key in ref) {
      val = ref[key];
      results.push(key);
    }
    return results;
  };

  Service.prototype.forEach = function(func) {
    var key, ref, results, val;
    ref = this.store;
    results = [];
    for (key in ref) {
      val = ref[key];
      results.push(func(key, val));
    }
    return results;
  };

  return Service;

})();

namespace('ru.geo.localstorage');

angular.module(['ru.geo.localstorage', '1.0.0'], []).constant('$localstorage', new ru.geo.localstorage.Service());

var indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

namespace('ru.geo.underscore');

ru.geo.underscore.Service = (function() {
  function Service() {
    var key, val;
    for (key in _) {
      val = _[key];
      this[key] = val;
    }
  }

  Service.prototype.getOrElse = function(value, defaultValue) {
    if (!(value != null) || isNaN(value)) {
      return defaultValue;
    }
    return value;
  };

  Service.prototype.update = function(dst, src) {
    var dstKeys, existingKeys, index, j, k, key, l, len, len1, len2, len3, m, ref, results, srcKeys, value;
    dstKeys = this.filter(this.keys(dst), function(key) {
      return !key.startsWith('$');
    });
    srcKeys = this.filter(this.keys(src), function(key) {
      return !key.startsWith('$');
    });
    for (j = 0, len = srcKeys.length; j < len; j++) {
      key = srcKeys[j];
      if (this.isArray(dst[key])) {
        ref = src[key];
        for (index = k = 0, len1 = ref.length; k < len1; index = ++k) {
          value = ref[index];
          dst[key][index] = value;
        }
        if (src[key].length < dst[key].length) {
          dst[key].splice(src[key].length, dst[key].length - src[key].length);
        }
      } else if (this.isObject(dst[key])) {
        this.update(dst[key], src[key]);
      } else {
        dst[key] = src[key];
      }
    }
    existingKeys = {};
    for (l = 0, len2 = srcKeys.length; l < len2; l++) {
      key = srcKeys[l];
      existingKeys[key] = 1;
    }
    results = [];
    for (m = 0, len3 = dstKeys.length; m < len3; m++) {
      key = dstKeys[m];
      if (existingKeys[key] == null) {
        if (this.isArray(dst[key])) {
          results.push(dst[key].splice(0, dst[key].length));
        } else if (this.isString(dst[key])) {
          results.push(dst[key] = '');
        } else {
          results.push(dst[key] = void 0);
        }
      } else {
        results.push(void 0);
      }
    }
    return results;
  };

  Service.prototype.getStringHash = function(object, ignored) {
    var key, value;
    if (ignored == null) {
      ignored = [];
    }
    return JSON.stringify((function() {
      var results;
      results = [];
      for (key in object) {
        value = object[key];
        if (!(_.isFunction(value)) && indexOf.call(ignored, key) < 0) {
          results.push(value);
        }
      }
      return results;
    })());
  };

  Service.prototype.getStringHashIgnoreUndefined = function(object, ignored) {
    var key, value;
    if (ignored == null) {
      ignored = [];
    }
    return JSON.stringify((function() {
      var results;
      results = [];
      for (key in object) {
        value = object[key];
        if (!(_.isFunction(value)) && indexOf.call(ignored, key) < 0 && !!value) {
          results.push(value);
        }
      }
      return results;
    })());
  };

  Service.prototype.getStringHashByFields = function(object, fields) {
    var key;
    if (fields == null) {
      fields = [];
    }
    return JSON.stringify((function() {
      var j, len, results;
      results = [];
      for (j = 0, len = fields.length; j < len; j++) {
        key = fields[j];
        if (!(_.isFunction(object[key]))) {
          results.push(object[key]);
        }
      }
      return results;
    })());
  };

  Service.prototype.uniqStringsArray = function(array) {
    var j, key, len, result, store;
    store = {};
    result = [];
    for (j = 0, len = array.length; j < len; j++) {
      key = array[j];
      if (store[key] == null) {
        store[key] = true;
        result.push(key);
      }
    }
    return result;
  };

  Service.prototype.stringHashCode = function(string) {
    var chr, hash, i, j, ref;
    hash = 0;
    if (string.length === 0) {
      return hash;
    }
    for (i = j = 0, ref = string.length; 0 <= ref ? j < ref : j > ref; i = 0 <= ref ? ++j : --j) {
      chr = string.charCodeAt(i);
      hash = (hash << 5) - hash + chr;
      hash |= 0;
    }
    return hash;
  };

  return Service;

})();

namespace('ru.geo.underscore');

angular.module(['ru.geo.underscore', '1.0.0'], []).constant('_', new ru.geo.underscore.Service());
